@@ -128,6 +128,9 @@ check_gold 1 gold-45-h.txt            tests/input-{4,5}.txt --cols=80 --highligh
 check_gold 1 gold-45-nb.txt           tests/input-{4,5}.txt --cols=80 --no-bold
 check_gold 1 gold-45-sas-h.txt        tests/input-{4,5}.txt --cols=80 --show-all-spaces --highlight
 check_gold 1 gold-45-sas-h-nb.txt     tests/input-{4,5}.txt --cols=80 --show-all-spaces --highlight --no-bold
+check_gold 1 gold-sas.txt             tests/input-{10,11}.txt --cols=80 --show-all-spaces
+check_gold 1 gold-sns.txt             tests/input-{10,11}.txt --cols=80 --show-no-spaces
+check_gold 1 gold-show-spaces.txt     tests/input-{10,11}.txt --cols=80
 check_gold 1 gold-45-h-nb.txt         tests/input-{4,5}.txt --cols=80 --highlight --no-bold
 check_gold 1 gold-45-ln.txt           tests/input-{4,5}.txt --cols=80 --line-numbers
 check_gold 1 gold-45-ln-color.txt     tests/input-{4,5}.txt --cols=80 --line-numbers --color-map='line-numbers:cyan'
@@ -158,9 +161,9 @@ check_gold 0 gold-identical-on.txt tests/input-{1,1}.txt -s
 check_gold 2 gold-bad-encoding.txt tests/input-{1,2}.txt --encoding=nonexistend_encoding
 check_gold 0 gold-recursive-with-exclude.txt --recursive -x c tests/{a,b} --cols=80
 check_gold 1 gold-recursive-with-exclude2.txt --recursive -x 'excl*' tests/test-with-exclude/{a,b} --cols=80
-check_gold 0 gold-exit-process-sub tests/input-1.txt <(cat tests/input-1.txt) --cols=80
+check_gold 0 gold-exit-process-sub tests/input-1.txt <(cat tests/input-1.txt) --no-headers --cols=80
 
-rm tests/permissions-{a,b}
+rm -f tests/permissions-{a,b}
 touch tests/permissions-{a,b}
 check_gold 0 gold-permissions-same.txt tests/permissions-{a,b} -P --cols=80
 
@@ -173,7 +176,7 @@ check_gold 1 gold-permissions-diff-text.txt tests/permissions-{a,b} -P --cols=80
 
 echo -e "\04" >> tests/permissions-b
 check_gold 1 gold-permissions-diff-binary.txt tests/permissions-{a,b} -P --cols=80
-rm tests/permissions-{a,b}
+rm -f tests/permissions-{a,b}
 
 if git show 4e86205629 &> /dev/null; then
   # We're in the repo, so test git.
@@ -209,7 +212,7 @@ function ensure_installed() {
 
 ensure_installed "black"
 echo 'Running black formatter...'
-if ! black icdiff --line-length 79 --check; then
+if ! black icdiff --quiet --line-length 79 --check; then
   echo ""
   echo 'Consider running `black icdiff --line-length 79`'
   fail
